@@ -103,7 +103,7 @@ public final class GroupAJAXRequest {
         }
         try {
             return Integer.parseInt(parameter.trim());
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create(name, parameter);
         }
     }
@@ -143,7 +143,7 @@ public final class GroupAJAXRequest {
         }
         try {
             return new Date(Long.parseLong(parameter.trim()));
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create(name, parameter);
         }
     }
@@ -155,7 +155,7 @@ public final class GroupAJAXRequest {
         }
         try {
             return new Date(Long.parseLong(parameter.trim()));
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create(name, parameter);
         }
     }
@@ -182,7 +182,7 @@ public final class GroupAJAXRequest {
         }
         try {
             return Integer.parseInt(parameter.trim());
-        } catch (final NumberFormatException e) {
+        } catch (NumberFormatException e) {
             throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create(name, parameter);
         }
     }
@@ -209,7 +209,7 @@ public final class GroupAJAXRequest {
         for (int i = 0; i < sa.length; i++) {
             try {
                 ret[i] = Integer.parseInt(sa[i].trim());
-            } catch (final NumberFormatException e) {
+            } catch (NumberFormatException e) {
                 throw AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create(name, parameter);
             }
         }
